@@ -5,7 +5,7 @@ use parent 'DBI';
 
 *errstr = \*DBI::errstr;
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 our $_dq_parser_cache = {};
 
 #-----------------------------------------------------------------------------
@@ -546,7 +546,7 @@ our $_dq_parser_cache = {};
 }
 
 1;
-__END__
+
 =pod
 
 =head1 NAME
@@ -1058,7 +1058,6 @@ Gryphon Shafer E<lt>gryphon@cpan.orgE<gt>.
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.4 or,
-at your option, any later version of Perl 5 you may have available.
+it under the same terms as Perl itself.
 
 =cut
